Struct LegacyRandomSplitter
pub struct LegacyRandomSplitter {
seed: i64,
}Expand description
A positional random number generator factory for the legacy Minecraft LCG algorithm. This can create random sources based on position, hash, or seed.
Fields
seed: i64Implementations
impl LegacyRandomSplitter
impl LegacyRandomSplitter
pub const fn new(seed: i64) -> LegacyRandomSplitter
pub const fn new(seed: i64) -> LegacyRandomSplitter
Creates a new LegacyRandomSplitter with the given seed.
This seed is used to initialize positional random sources.